@@ -53,7 +53,7 @@ class acp_extensions
 		$this->phpbb_container = $phpbb_container;
 		$this->php_ini = $this->phpbb_container->get('php_ini');
 
-		$this->user->add_lang(array('install', 'acp/extensions', 'migrator'));
+		$this->user->add_lang(array('install', 'acp/extensions', 'acp/modules', 'migrator'));
 
 		$this->page_title = 'ACP_EXTENSIONS';
 
@@ -151,13 +151,13 @@ class acp_extensions
 				$this->list_disabled_exts();
 				$this->list_available_exts();
 
+				$this->tpl_name = 'acp_ext_list';
+
 				$this->template->assign_vars(array(
 					'U_VERSIONCHECK_FORCE' 	=> $this->u_action . '&amp;action=list&amp;versioncheck_force=1',
 					'FORCE_UNSTABLE'		=> $this->config['extension_force_unstable'],
 					'U_ACTION' 				=> $this->u_action,
 				));
-
-				$this->tpl_name = 'acp_ext_list';
 			break;
 
 			case 'enable_pre':
@@ -180,19 +180,13 @@ class acp_extensions
 					redirect($this->u_action);
 				}
 
-				if (confirm_box(true))
-				{
-					redirect($this->u_action . '&amp;action=enable&amp;ext_name=' . urlencode($ext_name) . '&amp;hash=' . generate_link_hash('enable.' . $ext_name));
-				}
-				else
-				{
-					confirm_box(false, $this->user->lang('EXTENSION_ENABLE_CONFIRM', $md_manager->get_metadata('display-name')), build_hidden_fields(array(
-						'i'			=> $id,
-						'mode'		=> $mode,
-						'action'	=> 'enable_pre',
-						'ext_name'	=> $ext_name,
-					)));
-				}
+				$this->tpl_name = 'acp_ext_enable';
+
+				$this->template->assign_vars([
+					'S_PRE_STEP'		=> true,
+					'CONFIRM_MESSAGE'	=> $this->user->lang('EXTENSION_ENABLE_CONFIRM', $md_manager->get_metadata('display-name')),
+					'U_ENABLE'			=> $this->u_action . '&amp;action=enable&amp;ext_name=' . urlencode($ext_name) . '&amp;hash=' . generate_link_hash('enable.' . $ext_name),
+				]);
 			break;
 
 			case 'enable':
@@ -217,8 +211,9 @@ class acp_extensions
 						// Are we approaching the time limit? If so we want to pause the update and continue after refreshing
 						if ((time() - $start_time) >= $safe_time_limit)
 						{
+							$this->template->assign_var('S_NEXT_STEP', true);
+
 							meta_refresh(0, $this->u_action . '&amp;action=enable&amp;ext_name=' . urlencode($ext_name) . '&amp;hash=' . generate_link_hash('enable.' . $ext_name));
-							trigger_error('EXTENSION_ENABLE_IN_PROGRESS', E_USER_NOTICE);
 						}
 					}
 
@@ -234,29 +229,14 @@ class acp_extensions
 				}
 				catch (\phpbb\db\migration\exception $e)
 				{
-					trigger_error($this->user->lang('MIGRATION_EXCEPTION_ERROR', $e->getLocalisedMessage($this->user)), E_USER_WARNING);
+					$this->template->assign_var('MIGRATOR_ERROR', $e->getLocalisedMessage($this->user));
 				}
 
-				if ($this->request->is_ajax())
-				{
-					$actions = $this->output_actions('enabled', [
-						'DISABLE'	=> $this->u_action . '&amp;action=disable_pre&amp;ext_name=' . urlencode($ext_name),
-					]);
+				$this->tpl_name = 'acp_ext_enable';
 
-					$data = [
-						'EXT_ENABLE_SUCCESS'	=> true,
-						'ACTIONS'				=> $actions,
-						'REFRESH_DATA'			=> [
-							'url'	=> '',
-							'time'	=> 0,
-						],
-					];
-
-					$json_response = new \phpbb\json_response;
-					$json_response->send($data);
-				}
-
-				trigger_error($this->user->lang('EXTENSION_ENABLE_SUCCESS') . adm_back_link($this->u_action), E_USER_NOTICE);
+				$this->template->assign_vars([
+					'U_RETURN'		=> $this->u_action . '&amp;action=list',
+				]);
 			break;
 
 			case 'disable_pre':
@@ -265,19 +245,13 @@ class acp_extensions
 					redirect($this->u_action);
 				}
 
-				if (confirm_box(true))
-				{
-					redirect($this->u_action . '&amp;action=disable&amp;ext_name=' . urlencode($ext_name) . '&amp;hash=' . generate_link_hash('disable.' . $ext_name));
-				}
-				else
-				{
-					confirm_box(false, $this->user->lang('EXTENSION_DISABLE_CONFIRM', $md_manager->get_metadata('display-name')), build_hidden_fields(array(
-						'i'			=> $id,
-						'mode'		=> $mode,
-						'action'	=> 'disable_pre',
-						'ext_name'	=> $ext_name,
-					)));
-				}
+				$this->tpl_name = 'acp_ext_disable';
+
+				$this->template->assign_vars([
+					'S_PRE_STEP'		=> true,
+					'CONFIRM_MESSAGE'	=> $this->user->lang('EXTENSION_DISABLE_CONFIRM', $md_manager->get_metadata('display-name')),
+					'U_DISABLE'			=> $this->u_action . '&amp;action=disable&amp;ext_name=' . urlencode($ext_name) . '&amp;hash=' . generate_link_hash('disable.' . $ext_name),
+				]);
 			break;
 
 			case 'disable':
@@ -294,32 +268,15 @@ class acp_extensions
 						$this->template->assign_var('S_NEXT_STEP', true);
 
 						meta_refresh(0, $this->u_action . '&amp;action=disable&amp;ext_name=' . urlencode($ext_name) . '&amp;hash=' . generate_link_hash('disable.' . $ext_name));
-						trigger_error('EXTENSION_DISABLE_IN_PROGRESS', E_USER_NOTICE);
 					}
 				}
 				$this->log->add('admin', $this->user->data['user_id'], $this->user->ip, 'LOG_EXT_DISABLE', time(), array($ext_name));
 
-				if ($this->request->is_ajax())
-				{
-					$actions = $this->output_actions('disabled', [
-						'ENABLE'		=> $this->u_action . '&amp;action=enable_pre&amp;ext_name=' . urlencode($ext_name),
-						'DELETE_DATA'	=> $this->u_action . '&amp;action=delete_data_pre&amp;ext_name=' . urlencode($ext_name),
-					]);
+				$this->tpl_name = 'acp_ext_disable';
 
-					$data = [
-						'EXT_DISABLE_SUCCESS'	=> true,
-						'ACTIONS'				=> $actions,
-						'REFRESH_DATA'			=> [
-							'url'	=> '',
-							'time'	=> 0,
-						],
-					];
-
-					$json_response = new \phpbb\json_response;
-					$json_response->send($data);
-				}
-
-				trigger_error($this->user->lang('EXTENSION_DISABLE_SUCCESS') . adm_back_link($this->u_action), E_USER_NOTICE);
+				$this->template->assign_vars([
+					'U_RETURN'	=> $this->u_action . '&amp;action=list',
+				]);
 			break;
 
 			case 'delete_data_pre':
@@ -328,19 +285,13 @@ class acp_extensions
 					redirect($this->u_action);
 				}
 
-				if (confirm_box(true))
-				{
-					redirect($this->u_action . '&amp;action=delete_data&amp;ext_name=' . urlencode($ext_name) . '&amp;hash=' . generate_link_hash('delete_data.' . $ext_name));
-				}
-				else
-				{
-					confirm_box(false, $this->user->lang('EXTENSION_DELETE_DATA_CONFIRM', $md_manager->get_metadata('display-name')), build_hidden_fields(array(
-						'i'			=> $id,
-						'mode'		=> $mode,
-						'action'	=> 'delete_data_pre',
-						'ext_name'	=> $ext_name,
-					)));
-				}
+				$this->tpl_name = 'acp_ext_delete_data';
+
+				$this->template->assign_vars([
+					'S_PRE_STEP'		=> true,
+					'CONFIRM_MESSAGE'	=> $this->user->lang('EXTENSION_DELETE_DATA_CONFIRM', $md_manager->get_metadata('display-name')),
+					'U_PURGE'			=> $this->u_action . '&amp;action=delete_data&amp;ext_name=' . urlencode($ext_name) . '&amp;hash=' . generate_link_hash('delete_data.' . $ext_name),
+				]);
 			break;
 
 			case 'delete_data':
@@ -359,36 +310,20 @@ class acp_extensions
 							$this->template->assign_var('S_NEXT_STEP', true);
 
 							meta_refresh(0, $this->u_action . '&amp;action=delete_data&amp;ext_name=' . urlencode($ext_name) . '&amp;hash=' . generate_link_hash('delete_data.' . $ext_name));
-							trigger_error('EXTENSION_DELETE_DATA_IN_PROGRESS', E_USER_NOTICE);
 						}
 					}
 					$this->log->add('admin', $this->user->data['user_id'], $this->user->ip, 'LOG_EXT_PURGE', time(), array($ext_name));
 				}
 				catch (\phpbb\db\migration\exception $e)
 				{
-					trigger_error($this->user->lang('MIGRATION_EXCEPTION_ERROR', $e->getLocalisedMessage($this->user)), E_USER_WARNING);
+					$this->template->assign_var('MIGRATOR_ERROR', $e->getLocalisedMessage($this->user));
 				}
 
-				if ($this->request->is_ajax())
-				{
-					$actions = $this->output_actions('disabled', [
-						'ENABLE'		=> $this->u_action . '&amp;action=enable_pre&amp;ext_name=' . urlencode($ext_name),
-					]);
+				$this->tpl_name = 'acp_ext_delete_data';
 
-					$data = [
-						'EXT_DELETE_DATA_SUCCESS'	=> true,
-						'ACTIONS'					=> $actions,
-						'REFRESH_DATA'				=> [
-							'url'	=> '',
-							'time'	=> 0,
-						],
-					];
-
-					$json_response = new \phpbb\json_response;
-					$json_response->send($data);
-				}
-
-				trigger_error($this->user->lang('EXTENSION_DELETE_DATA_SUCCESS') . adm_back_link($this->u_action), E_USER_NOTICE);
+				$this->template->assign_vars([
+					'U_RETURN'	=> $this->u_action . '&amp;action=list',
+				]);
 			break;
 
 			case 'details':
@@ -640,7 +575,7 @@ class acp_extensions
 			catch (exception_interface $e)
 			{
 				$message = call_user_func_array(array($this->user, 'lang'), array_merge(array($e->getMessage()), $e->get_parameters()));
-				$this->template->assign_block_vars('disabled', array(
+				$this->template->assign_block_vars('not_installed', array(
 					'META_DISPLAY_NAME'		=> $this->user->lang('EXTENSION_INVALID_LIST', $name, $message),
 					'S_VERSIONCHECK'		=> false,
 				));
@@ -654,9 +589,9 @@ class acp_extensions
 			$block_vars['NAME'] = $name;
 			$block_vars['U_DETAILS'] = $this->u_action . '&amp;action=details&amp;ext_name=' . urlencode($name);
 
-			$this->template->assign_block_vars('disabled', $block_vars);
+			$this->template->assign_block_vars('not_installed', $block_vars);
 
-			$this->output_actions('disabled', array(
+			$this->output_actions('not_installed', array(
 				'ENABLE'		=> $this->u_action . '&amp;action=enable_pre&amp;ext_name=' . urlencode($name),
 			));
 		}
@@ -667,37 +602,17 @@ class acp_extensions
 	*
 	* @param string $block
 	* @param array $actions
-	* @return array List of actions to be performed on the extension
 	*/
 	private function output_actions($block, $actions)
 	{
-		$vars_ary = array();
-		foreach ($actions as $lang => $options)
+		foreach ($actions as $lang => $url)
 		{
-			$url = $options;
-			if (is_array($options))
-			{
-				$url = $options['url'];
-			}
-
-			$vars = array(
+			$this->template->assign_block_vars($block . '.actions', [
 				'L_ACTION'			=> $this->user->lang('EXTENSION_' . $lang),
 				'L_ACTION_EXPLAIN'	=> (isset($this->user->lang['EXTENSION_' . $lang . '_EXPLAIN'])) ? $this->user->lang('EXTENSION_' . $lang . '_EXPLAIN') : '',
 				'U_ACTION'			=> $url,
-				'ACTION_AJAX'		=> 'ext_' . strtolower($lang),
-			);
-
-			if (isset($options['color']))
-			{
-				$vars['COLOR'] = $options['color'];
-			}
-
-			$this->template->assign_block_vars($block . '.actions', $vars);
-
-			$vars_ary[] = $vars;
+			]);
 		}
-
-		return $vars_ary;
 	}
 
 	/**
